@@ -50,7 +50,7 @@ pub struct Global {
 impl Global {
     pub async fn run(self) -> Result<()> {
         let settings = Settings::try_get()?;
-        let config = Config::get().await;
+        let config = Config::get().await?;
         local(
             &config,
             &settings.global_tools_file(),
