@@ -7,6 +7,49 @@ use self_update::{Status, cargo_crate_version};
 use crate::cli::version::{ARCH, OS};
 use crate::config::Settings;
 use crate::{cmd, env};
+use std::collections::BTreeMap;
+use std::fs;
+use std::path::PathBuf;
+
+#[derive(Debug, Default, serde::Deserialize)]
+struct InstructionsToml {
+    message: Option<String>,
+    #[serde(flatten)]
+    commands: BTreeMap<String, String>,
+}
+
+fn read_instructions_file(path: &PathBuf) -> Option<String> {
+    let body = fs::read_to_string(path).ok()?;
+    let parsed: InstructionsToml = toml::from_str(&body).ok()?;
+    if let Some(msg) = parsed.message {
+        return Some(msg);
+    }
+    if let Some((_k, v)) = parsed.commands.into_iter().next() {
+        return Some(v);
+    }
+    None
+}
+
+pub fn upgrade_instructions_text() -> Option<String> {
+    if let Some(path) = &*env::MISE_SELF_UPDATE_INSTRUCTIONS {
+        if let Some(msg) = read_instructions_file(path) {
+            return Some(msg);
+        }
+    }
+    None
+}
+
+/// Appends self-update guidance and packaging instructions (if any) to a message.
+pub fn append_self_update_instructions(mut message: String) -> String {
+    if SelfUpdate::is_available() {
+        message.push_str("\nRun `mise self-update` to update mise");
+    }
+    if let Some(instructions) = upgrade_instructions_text() {
+        message.push('\n');
+        message.push_str(&instructions);
+    }
+    message
+}
 
 /// Updates mise itself.
 ///
@@ -37,6 +80,9 @@ pub struct SelfUpdate {
 impl SelfUpdate {
     pub async fn run(self) -> Result<()> {
         if !Self::is_available() && !self.force {
+            if let Some(instructions) = upgrade_instructions_text() {
+                warn!("{}", instructions);
+            }
             bail!("mise is installed via a package manager, cannot update");
         }
         let status = self.do_update()?;
@@ -100,21 +146,11 @@ impl SelfUpdate {
     }
 
     pub fn is_available() -> bool {
-        !std::fs::canonicalize(&*env::MISE_BIN)
-            .ok()
-            .and_then(|p| p.parent().map(|p| p.to_path_buf()))
-            .and_then(|p| p.parent().map(|p| p.to_path_buf()))
-            .map(|p| {
-                p.join("lib").join(".disable-self-update").exists() // kept for compatibility, see #4476
-                    || p.join("lib")
-                        .join("mise")
-                        .join(".disable-self-update")
-                        .exists()
-                    || p.join("lib64")
-                        .join("mise")
-                        .join(".disable-self-update")
-                        .exists()
-            })
-            .unwrap_or_default()
+        if let Some(b) = *env::MISE_SELF_UPDATE_AVAILABLE {
+            return b;
+        }
+        let has_disable = env::MISE_SELF_UPDATE_DISABLED_PATH.is_some();
+        let has_instructions = env::MISE_SELF_UPDATE_INSTRUCTIONS.is_some();
+        !(has_disable || has_instructions)
     }
 }
