@@ -8,14 +8,8 @@ use std::{
     sync::Arc,
 };
 
-use eyre::{Result, eyre};
-use idiomatic_version::IdiomaticVersionFile;
-use serde_derive::Deserialize;
-use std::sync::LazyLock as Lazy;
-use tool_versions::ToolVersions;
-use versions::Versioning;
-
 use crate::cli::args::{BackendArg, ToolArg};
+use crate::config::config_file::min_version::MinVersionSpec;
 use crate::config::config_file::mise_toml::MiseToml;
 use crate::config::env_directive::EnvDirective;
 use crate::config::{AliasMap, Settings, settings};
@@ -29,11 +23,17 @@ use crate::toolset::{ToolRequest, ToolRequestSet, ToolSource, ToolVersionList, T
 use crate::ui::{prompt, style};
 use crate::watch_files::WatchFile;
 use crate::{backend, config, dirs, env, file, hash};
+use eyre::{Result, eyre};
+use idiomatic_version::IdiomaticVersionFile;
+use serde_derive::Deserialize;
+use std::sync::LazyLock as Lazy;
+use tool_versions::ToolVersions;
 
 use super::Config;
 
 pub mod config_root;
 pub mod idiomatic_version;
+pub mod min_version;
 pub mod mise_toml;
 pub mod toml;
 pub mod tool_versions;
@@ -47,8 +47,8 @@ pub enum ConfigFileType {
 
 pub trait ConfigFile: Debug + Send + Sync {
     fn get_path(&self) -> &Path;
-    fn min_version(&self) -> &Option<Versioning> {
-        &None
+    fn min_version(&self) -> Option<&MinVersionSpec> {
+        None
     }
     /// gets the project directory for the config
     /// if it's a global/system config, returns None
@@ -217,8 +217,8 @@ impl dyn ConfigFile {
     }
 }
 
-fn init(path: &Path) -> Arc<dyn ConfigFile> {
-    match detect_config_file_type(path) {
+async fn init(path: &Path) -> Arc<dyn ConfigFile> {
+    match detect_config_file_type(path).await {
         Some(ConfigFileType::MiseToml) => Arc::new(MiseToml::init(path)),
         Some(ConfigFileType::ToolVersions) => Arc::new(ToolVersions::init(path)),
         Some(ConfigFileType::IdiomaticVersion) => {
@@ -228,30 +228,30 @@ fn init(path: &Path) -> Arc<dyn ConfigFile> {
     }
 }
 
-pub fn parse_or_init(path: &Path) -> eyre::Result<Arc<dyn ConfigFile>> {
+pub async fn parse_or_init(path: &Path) -> eyre::Result<Arc<dyn ConfigFile>> {
     let path = if path.is_dir() {
         path.join(&*env::MISE_DEFAULT_CONFIG_FILENAME)
     } else {
         path.into()
     };
     let cf = match path.exists() {
-        true => parse(&path)?,
-        false => init(&path),
+        true => parse(&path).await?,
+        false => init(&path).await,
     };
     Ok(cf)
 }
 
-pub fn parse(path: &Path) -> Result<Arc<dyn ConfigFile>> {
+pub async fn parse(path: &Path) -> Result<Arc<dyn ConfigFile>> {
     if let Ok(settings) = Settings::try_get() {
         if settings.paranoid {
             trust_check(path)?;
         }
     }
-    match detect_config_file_type(path) {
+    match detect_config_file_type(path).await {
         Some(ConfigFileType::MiseToml) => Ok(Arc::new(MiseToml::from_file(path)?)),
         Some(ConfigFileType::ToolVersions) => Ok(Arc::new(ToolVersions::from_file(path)?)),
         Some(ConfigFileType::IdiomaticVersion) => {
-            Ok(Arc::new(IdiomaticVersionFile::from_file(path)?))
+            Ok(Arc::new(IdiomaticVersionFile::from_file(path).await?))
         }
         #[allow(clippy::box_default)]
         _ => Ok(Arc::new(MiseToml::default())),
@@ -462,24 +462,29 @@ fn trust_file_hash(path: &Path) -> eyre::Result<bool> {
     Ok(hash == actual)
 }
 
-fn detect_config_file_type(path: &Path) -> Option<ConfigFileType> {
+async fn filename_is_idiomatic(file_name: String) -> bool {
+    for b in backend::list() {
+        match b.idiomatic_filenames().await {
+            Ok(filenames) => {
+                if filenames.contains(&file_name) {
+                    return true;
+                }
+            }
+            Err(e) => {
+                debug!("idiomatic_filenames failed for {}: {:?}", b, e);
+            }
+        }
+    }
+    false
+}
+
+async fn detect_config_file_type(path: &Path) -> Option<ConfigFileType> {
     match path
         .file_name()
         .and_then(|f| f.to_str())
         .unwrap_or("mise.toml")
     {
-        f if backend::list()
-            .iter()
-            .any(|b| match b.idiomatic_filenames() {
-                Ok(filenames) => filenames.contains(&f.to_string()),
-                Err(e) => {
-                    debug!("idiomatic_filenames failed for {}: {:?}", b, e);
-                    false
-                }
-            }) =>
-        {
-            Some(ConfigFileType::IdiomaticVersion)
-        }
+        f if filename_is_idiomatic(f.to_string()).await => Some(ConfigFileType::IdiomaticVersion),
         f if env::MISE_OVERRIDE_TOOL_VERSIONS_FILENAMES
             .as_ref()
             .is_some_and(|o| o.contains(f)) =>
@@ -530,27 +535,27 @@ mod tests {
 
     use super::*;
 
-    #[test]
-    fn test_detect_config_file_type() {
+    #[tokio::test]
+    async fn test_detect_config_file_type() {
         env::set_var("MISE_EXPERIMENTAL", "true");
         assert_eq!(
-            detect_config_file_type(Path::new("/foo/bar/.nvmrc")),
+            detect_config_file_type(Path::new("/foo/bar/.nvmrc")).await,
             Some(ConfigFileType::IdiomaticVersion)
         );
         assert_eq!(
-            detect_config_file_type(Path::new("/foo/bar/.ruby-version")),
+            detect_config_file_type(Path::new("/foo/bar/.ruby-version")).await,
             Some(ConfigFileType::IdiomaticVersion)
         );
         assert_eq!(
-            detect_config_file_type(Path::new("/foo/bar/.test-tool-versions")),
+            detect_config_file_type(Path::new("/foo/bar/.test-tool-versions")).await,
             Some(ConfigFileType::ToolVersions)
         );
         assert_eq!(
-            detect_config_file_type(Path::new("/foo/bar/mise.toml")),
+            detect_config_file_type(Path::new("/foo/bar/mise.toml")).await,
             Some(ConfigFileType::MiseToml)
         );
         assert_eq!(
-            detect_config_file_type(Path::new("/foo/bar/rust-toolchain.toml")),
+            detect_config_file_type(Path::new("/foo/bar/rust-toolchain.toml")).await,
             Some(ConfigFileType::IdiomaticVersion)
         );
     }
