@@ -176,6 +176,61 @@ pub static ARGV0: Lazy<String> = Lazy::new(|| ARGS.read().unwrap()[0].to_string(
 pub static MISE_BIN_NAME: Lazy<&str> = Lazy::new(|| filename(&ARGV0));
 pub static MISE_LOG_FILE: Lazy<Option<PathBuf>> = Lazy::new(|| var_path("MISE_LOG_FILE"));
 pub static MISE_LOG_FILE_LEVEL: Lazy<Option<LevelFilter>> = Lazy::new(log_file_level);
+fn find_in_tree(base: &Path, rels: &[&[&str]]) -> Option<PathBuf> {
+    for rel in rels {
+        let mut p = base.to_path_buf();
+        for part in *rel {
+            p = p.join(part);
+        }
+        if p.exists() {
+            return Some(p);
+        }
+    }
+    None
+}
+
+fn mise_install_base() -> Option<PathBuf> {
+    std::fs::canonicalize(&*MISE_BIN)
+        .ok()
+        .and_then(|p| p.parent().map(|p| p.to_path_buf()))
+        .and_then(|p| p.parent().map(|p| p.to_path_buf()))
+}
+
+pub static MISE_SELF_UPDATE_INSTRUCTIONS: Lazy<Option<PathBuf>> = Lazy::new(|| {
+    if let Some(p) = var_path("MISE_SELF_UPDATE_INSTRUCTIONS") {
+        return Some(p);
+    }
+    let base = mise_install_base()?;
+    // search lib/, lib/mise/, lib64/mise/
+    find_in_tree(
+        &base,
+        &[
+            &["lib", "mise-self-update-instructions.toml"],
+            &["lib", "mise", "mise-self-update-instructions.toml"],
+            &["lib64", "mise", "mise-self-update-instructions.toml"],
+        ],
+    )
+});
+pub static MISE_SELF_UPDATE_AVAILABLE: Lazy<Option<bool>> = Lazy::new(|| {
+    if var_is_true("MISE_SELF_UPDATE_AVAILABLE") {
+        Some(true)
+    } else if var_is_false("MISE_SELF_UPDATE_AVAILABLE") {
+        Some(false)
+    } else {
+        None
+    }
+});
+pub static MISE_SELF_UPDATE_DISABLED_PATH: Lazy<Option<PathBuf>> = Lazy::new(|| {
+    let base = mise_install_base()?;
+    find_in_tree(
+        &base,
+        &[
+            &["lib", ".disable-self-update"],
+            &["lib", "mise", ".disable-self-update"],
+            &["lib64", "mise", ".disable-self-update"],
+        ],
+    )
+});
 pub static MISE_LOG_HTTP: Lazy<bool> = Lazy::new(|| var_is_true("MISE_LOG_HTTP"));
 
 pub static __USAGE: Lazy<Option<String>> = Lazy::new(|| var("__USAGE").ok());
@@ -231,6 +286,8 @@ pub static LINUX_DISTRO: Lazy<Option<String>> = Lazy::new(linux_distro);
 pub static PREFER_OFFLINE: Lazy<AtomicBool> =
     Lazy::new(|| prefer_offline(&ARGS.read().unwrap()).into());
 pub static OFFLINE: Lazy<bool> = Lazy::new(|| offline(&ARGS.read().unwrap()));
+pub static WARN_ON_MISSING_REQUIRED_ENV: Lazy<bool> =
+    Lazy::new(|| warn_on_missing_required_env(&ARGS.read().unwrap()));
 /// essentially, this is whether we show spinners or build output on runtime install
 pub static PRISTINE_ENV: Lazy<EnvMap> =
     Lazy::new(|| get_pristine_env(&__MISE_DIFF, vars().collect()));
@@ -492,6 +549,22 @@ fn prefer_offline(args: &[String]) -> bool {
         .unwrap_or_default()
 }
 
+/// returns true if missing required env vars should produce warnings instead of errors
+fn warn_on_missing_required_env(args: &[String]) -> bool {
+    // Check if we're running in a command that should warn instead of error
+    args.iter()
+        .take_while(|a| *a != "--")
+        .filter(|a| !a.starts_with('-'))
+        .nth(1)
+        .map(|a| {
+            [
+                "hook-env", // Shell activation should not break the shell
+            ]
+            .contains(&a.as_str())
+        })
+        .unwrap_or_default()
+}
+
 fn environment(args: &[String]) -> Vec<String> {
     let arg_defs = HashSet::from(["--profile", "-P", "--env", "-E"]);
 
