@@ -41,7 +41,7 @@ impl DenoPlugin {
         })
     }
 
-    fn test_deno(&self, tv: &ToolVersion, pr: &Box<dyn SingleReport>) -> Result<()> {
+    fn test_deno(&self, tv: &ToolVersion, pr: &dyn SingleReport) -> Result<()> {
         pr.set_message("deno -V".into());
         CmdLineRunner::new(self.deno_bin(tv))
             .with_pr(pr)
@@ -49,7 +49,7 @@ impl DenoPlugin {
             .execute()
     }
 
-    async fn download(&self, tv: &ToolVersion, pr: &Box<dyn SingleReport>) -> Result<PathBuf> {
+    async fn download(&self, tv: &ToolVersion, pr: &dyn SingleReport) -> Result<PathBuf> {
         let settings = Settings::get();
         let url = format!(
             "https://dl.deno.land/release/v{}/deno-{}-{}.zip",
@@ -68,12 +68,7 @@ impl DenoPlugin {
         Ok(tarball_path)
     }
 
-    fn install(
-        &self,
-        tv: &ToolVersion,
-        pr: &Box<dyn SingleReport>,
-        tarball_path: &Path,
-    ) -> Result<()> {
+    fn install(&self, tv: &ToolVersion, pr: &dyn SingleReport, tarball_path: &Path) -> Result<()> {
         let filename = tarball_path.file_name().unwrap().to_string_lossy();
         pr.set_message(format!("extract {filename}"));
         file::remove_all(tv.install_path())?;
@@ -91,7 +86,7 @@ impl DenoPlugin {
         Ok(())
     }
 
-    fn verify(&self, tv: &ToolVersion, pr: &Box<dyn SingleReport>) -> Result<()> {
+    fn verify(&self, tv: &ToolVersion, pr: &dyn SingleReport) -> Result<()> {
         self.test_deno(tv, pr)
     }
 }
@@ -115,7 +110,7 @@ impl Backend for DenoPlugin {
         Ok(versions)
     }
 
-    fn idiomatic_filenames(&self) -> Result<Vec<String>> {
+    async fn idiomatic_filenames(&self) -> Result<Vec<String>> {
         Ok(vec![".deno-version".into()])
     }
 
@@ -124,10 +119,10 @@ impl Backend for DenoPlugin {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> Result<ToolVersion> {
-        let tarball_path = self.download(&tv, &ctx.pr).await?;
+        let tarball_path = self.download(&tv, ctx.pr.as_ref()).await?;
         self.verify_checksum(ctx, &mut tv, &tarball_path)?;
-        self.install(&tv, &ctx.pr, &tarball_path)?;
-        self.verify(&tv, &ctx.pr)?;
+        self.install(&tv, ctx.pr.as_ref(), &tarball_path)?;
+        self.verify(&tv, ctx.pr.as_ref())?;
 
         Ok(tv)
     }
