@@ -52,7 +52,7 @@ impl NodePlugin {
             .fetch_tarball(
                 ctx,
                 tv,
-                &ctx.pr,
+                ctx.pr.as_ref(),
                 &opts.binary_tarball_url,
                 &opts.binary_tarball_path,
                 &opts.version,
@@ -111,7 +111,8 @@ impl NodePlugin {
                     &TarOptions {
                         format: TarFormat::TarGz,
                         strip_components: 1,
-                        pr: Some(&ctx.pr),
+                        pr: Some(ctx.pr.as_ref()),
+                        ..Default::default()
                     },
                 )?;
                 Ok(())
@@ -155,7 +156,7 @@ impl NodePlugin {
         self.fetch_tarball(
             ctx,
             tv,
-            &ctx.pr,
+            ctx.pr.as_ref(),
             &opts.source_tarball_url,
             &opts.source_tarball_path,
             &opts.version,
@@ -168,7 +169,7 @@ impl NodePlugin {
             opts.build_dir.parent().unwrap(),
             &TarOptions {
                 format: TarFormat::TarGz,
-                pr: Some(&ctx.pr),
+                pr: Some(ctx.pr.as_ref()),
                 ..Default::default()
             },
         )?;
@@ -182,7 +183,7 @@ impl NodePlugin {
         &self,
         ctx: &InstallContext,
         tv: &mut ToolVersion,
-        pr: &Box<dyn SingleReport>,
+        pr: &dyn SingleReport,
         url: &Url,
         local: &Path,
         version: &str,
@@ -209,7 +210,7 @@ impl NodePlugin {
     fn sh<'a>(&self, ctx: &'a InstallContext, opts: &BuildOpts) -> eyre::Result<CmdLineRunner<'a>> {
         let mut cmd = CmdLineRunner::new("sh")
             .prepend_path(opts.path.clone())?
-            .with_pr(&ctx.pr)
+            .with_pr(ctx.pr.as_ref())
             .current_dir(&opts.build_dir)
             .arg("-c");
         if let Some(cflags) = &*env::MISE_NODE_CFLAGS {
@@ -236,8 +237,12 @@ impl NodePlugin {
     ) -> Result<String> {
         let tarball_name = tarball.file_name().unwrap().to_string_lossy().to_string();
         let shasums_file = tarball.parent().unwrap().join("SHASUMS256.txt");
-        HTTP.download_file(self.shasums_url(version)?, &shasums_file, Some(&ctx.pr))
-            .await?;
+        HTTP.download_file(
+            self.shasums_url(version)?,
+            &shasums_file,
+            Some(ctx.pr.as_ref()),
+        )
+        .await?;
         if Settings::get().node.gpg_verify != Some(false) && version.starts_with("2") {
             self.verify_with_gpg(ctx, &shasums_file, version).await?;
         }
@@ -259,7 +264,10 @@ impl NodePlugin {
         }
         let sig_file = shasums_file.with_extension("asc");
         let sig_url = format!("{}.sig", self.shasums_url(v)?);
-        if let Err(e) = HTTP.download_file(sig_url, &sig_file, Some(&ctx.pr)).await {
+        if let Err(e) = HTTP
+            .download_file(sig_url, &sig_file, Some(ctx.pr.as_ref()))
+            .await
+        {
             if matches!(http::error_code(&e), Some(404)) {
                 warn!("gpg signature not found, skipping verification");
                 return Ok(());
@@ -274,7 +282,7 @@ impl NodePlugin {
             .arg("--verify")
             .arg(sig_file)
             .arg(shasums_file)
-            .with_pr(&ctx.pr)
+            .with_pr(ctx.pr.as_ref())
             .execute()?;
         Ok(())
     }
@@ -307,7 +315,7 @@ impl NodePlugin {
         &self,
         config: &Arc<Config>,
         tv: &ToolVersion,
-        pr: &Box<dyn SingleReport>,
+        pr: &dyn SingleReport,
     ) -> Result<()> {
         let body = file::read_to_string(&*env::MISE_NODE_DEFAULT_PACKAGES_FILE).unwrap_or_default();
         for package in body.lines() {
@@ -336,11 +344,7 @@ impl NodePlugin {
         Ok(())
     }
 
-    fn enable_default_corepack_shims(
-        &self,
-        tv: &ToolVersion,
-        pr: &Box<dyn SingleReport>,
-    ) -> Result<()> {
+    fn enable_default_corepack_shims(&self, tv: &ToolVersion, pr: &dyn SingleReport) -> Result<()> {
         pr.set_message("enable corepack shims".into());
         let corepack = self.corepack_path(tv);
         CmdLineRunner::new(corepack)
@@ -355,7 +359,7 @@ impl NodePlugin {
         &self,
         config: &Arc<Config>,
         tv: &ToolVersion,
-        pr: &Box<dyn SingleReport>,
+        pr: &dyn SingleReport,
     ) -> Result<()> {
         pr.set_message("node -v".into());
         CmdLineRunner::new(self.node_path(tv))
@@ -369,7 +373,7 @@ impl NodePlugin {
         &self,
         config: &Arc<Config>,
         tv: &ToolVersion,
-        pr: &Box<dyn SingleReport>,
+        pr: &dyn SingleReport,
     ) -> Result<()> {
         pr.set_message("npm -v".into());
         CmdLineRunner::new(self.npm_path(tv))
@@ -455,11 +459,11 @@ impl Backend for NodePlugin {
         Ok(aliases)
     }
 
-    fn idiomatic_filenames(&self) -> Result<Vec<String>> {
+    async fn idiomatic_filenames(&self) -> Result<Vec<String>> {
         Ok(vec![".node-version".into(), ".nvmrc".into()])
     }
 
-    fn parse_idiomatic_file(&self, path: &Path) -> Result<String> {
+    async fn parse_idiomatic_file(&self, path: &Path) -> Result<String> {
         let body = file::read_to_string(path)?;
         // strip comments
         let body = body.split('#').next().unwrap_or_default().to_string();
@@ -490,19 +494,19 @@ impl Backend for NodePlugin {
             self.install_precompiled(ctx, &mut tv, &opts).await?;
         }
         debug!("{:?}: checking installation is working as expected", self);
-        self.test_node(&ctx.config, &tv, &ctx.pr).await?;
+        self.test_node(&ctx.config, &tv, ctx.pr.as_ref()).await?;
         if !cfg!(windows) {
             self.install_npm_shim(&tv)?;
         }
-        self.test_npm(&ctx.config, &tv, &ctx.pr).await?;
+        self.test_npm(&ctx.config, &tv, ctx.pr.as_ref()).await?;
         if let Err(err) = self
-            .install_default_packages(&ctx.config, &tv, &ctx.pr)
+            .install_default_packages(&ctx.config, &tv, ctx.pr.as_ref())
             .await
         {
             warn!("failed to install default npm packages: {err:#}");
         }
         if *env::MISE_NODE_COREPACK && self.corepack_path(&tv).exists() {
-            self.enable_default_corepack_shims(&tv, &ctx.pr)?;
+            self.enable_default_corepack_shims(&tv, ctx.pr.as_ref())?;
         }
 
         Ok(tv)
