@@ -1,3 +1,5 @@
+use std::sync::Arc;
+
 use eyre::Result;
 use itertools::Itertools;
 
@@ -35,25 +37,33 @@ impl ToolsetBuilder {
         self
     }
 
-    pub fn build(self, config: &Config) -> Result<Toolset> {
+    pub async fn build(self, config: &Arc<Config>) -> Result<Toolset> {
         let mut toolset = Toolset {
             ..Default::default()
         };
-        self.load_config_files(config, &mut toolset)?;
-        self.load_runtime_env(&mut toolset, env::vars().collect())?;
-        self.load_runtime_args(&mut toolset)?;
-        if let Err(err) = toolset.resolve() {
-            if Error::is_argument_err(&err) {
-                return Err(err);
+        measure!("toolset_builder::build::load_config_files", {
+            self.load_config_files(config, &mut toolset)?;
+        });
+        measure!("toolset_builder::build::load_runtime_env", {
+            self.load_runtime_env(&mut toolset, env::vars().collect())?;
+        });
+        measure!("toolset_builder::build::load_runtime_args", {
+            self.load_runtime_args(&mut toolset)?;
+        });
+        measure!("toolset_builder::build::resolve", {
+            if let Err(err) = toolset.resolve(config).await {
+                if Error::is_argument_err(&err) {
+                    return Err(err);
+                }
+                warn!("failed to resolve toolset: {err}");
             }
-            warn!("failed to resolve toolset: {err}");
-        }
+        });
 
         time!("toolset::builder::build");
         Ok(toolset)
     }
 
-    fn load_config_files(&self, config: &Config, ts: &mut Toolset) -> eyre::Result<()> {
+    fn load_config_files(&self, config: &Arc<Config>, ts: &mut Toolset) -> eyre::Result<()> {
         for cf in config.config_files.values().rev() {
             if self.global_only && !config::is_global_config(cf.get_path()) {
                 continue;
@@ -74,11 +84,11 @@ impl ToolsetBuilder {
                     // ignore MISE_INSTALL_VERSION
                     continue;
                 }
-                let fa: BackendArg = plugin_name.as_str().into();
+                let ba: Arc<BackendArg> = Arc::new(plugin_name.as_str().into());
                 let source = ToolSource::Environment(k, v.clone());
                 let mut env_ts = Toolset::new(source.clone());
                 for v in v.split_whitespace() {
-                    let tvr = ToolRequest::new(fa.clone(), v, source.clone())?;
+                    let tvr = ToolRequest::new(ba.clone(), v, source.clone())?;
                     env_ts.add_version(tvr);
                 }
                 ts.merge(env_ts);
